﻿using System;
using System.Windows.Forms;

namespace CS_FieldCalibration
{
    /// <summary>
    /// In the event that a connected instrument is not one of the
    /// supported instruments, this dialog is displayed and offers
    /// the user the choice of using the SCPI for one of the 
    /// supported instruments.
    /// </summary>
    public partial class ChooseModel : Form
    {
        public ChooseModel(string connectedInstrument, string[] compatibleInstruments)
        {
            InitializeComponent();

            mConnectedInstrument.Text = connectedInstrument;

            mCompatibleInstrument.Items.Clear();
            mCompatibleInstrument.Items.AddRange(compatibleInstruments);
            mCompatibleInstrument.SelectedIndex = 0;

            // Set the accept/cancel buttons
            AcceptButton = mOkButton;
            CancelButton = mCancelButton;
        }

        /// <summary>
        /// Auto-property for compatible instrument
        /// </summary>
        public string CompatibleInstrument { get; set; }

        /// <summary>
        /// Process the "OK" key...
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void mOkButton_Click(object sender, EventArgs e)
        {
            // Cache the answer
            CompatibleInstrument = (mCompatibleInstrument.SelectedIndex < 0)
                       ? ""
                       : mCompatibleInstrument.Items[mCompatibleInstrument.SelectedIndex].ToString();

            // Close the form.
            DialogResult = DialogResult.OK;
            Close();
        }
    }
}
