﻿using System;
using System.Globalization;
using Ivi.Visa.Interop;

namespace CS_FieldCalibration
{
    /// <summary>
    /// VisaSession aggregates the operations required to open and
    /// close a VISA session using Ivi.Visa.Interop.  It exposes
    /// the session to derived classes.
    /// 
    /// This class uses Ivi.Visa.Interop (rather than VisaComLib)
    /// so the program can connect to the instrument using either
    /// Agilent I/O or National Instruments VISA.
    /// </summary>
    public class VisaSession
    {
        protected static ResourceManager mResourceManager = new ResourceManager();
        protected IMessage mSession;
        // Number formats to/from the instruments are in fixed format -- use the US style for handling these
        protected readonly CultureInfo mFixedCulture = new CultureInfo("en-US");

        /// <summary>
        /// Open a VISA session for the specified VISA resource string.
        /// </summary>
        /// <param name="resource">VISA resource, may be an alias</param>
        protected void OpenSession(string resource)
        {
            const String options = "";
            const int openTimeout = 2000; // ms
            IVisaSession session = mResourceManager.Open(resource, AccessMode.EXCLUSIVE_LOCK, openTimeout, options);

            // "Cast" (which does QueryInterface) the VISA Session into the form we need
            mSession = (IMessage)session;
            mSession.SendEndEnabled = false;
            mSession.TerminationCharacter = (byte)'\n';
            mSession.TerminationCharacterEnabled = true;
            mSession.Timeout = 5000; // ms            
        }

        /// <summary>
        /// Close the VISA session
        /// </summary>
        protected void CloseSession()
        {
            if (mSession != null)
            {
                mSession.Close();
                mSession = null;
            }
        }

        /// <summary>
        /// Indicate if the VISA session has been opened
        /// </summary>
        /// <returns></returns>
        protected bool IsSessionOpen()
        {
            return mSession != null;
        }
    }
}
