Imports AgM9392Lib
Imports System.Reflection.Emit

Module Module1

    '/******************************************************************************
    '*  Copyright (c) 2010 Agilent Technologies Inc.  All rights reserved.
    '*
    '* You have a royalty-free right to use, modify, reproduce and distribute
    '* the sample application files (and/or any modified version) in any way
    '* you find useful, provided that you agree that Agilent Technologies has no
    '* warranty, obligations or liability for any sample application files.
    '*
    '* Agilent Technologies provides programming examples for illustration only,
    '* This sample program assumes that you are familiar with the programming
    '* language being demonstrated and the tools used to create and debug
    '* procedures. Agilent Technologies support engineers can help explain the
    '* functionality of Agilent Technologies software components and associated
    '* commands, but they will not modify these samples to provide added
    '* functionality or construct procedures to meet your specific needs.
    '*****************************************************************************/
    '///
    '/// Agilent IVI-C Driver Example Program
    '/// 
    '/// Initializes the driver, reads a few Identity interface
    '/// properties, and initiates instrument specific functionality.
    '/// 
    '/// Runs in simulation mode without an instrument.
    '/// 

    Function binaryPrompt(ByVal label As String, ByVal defVal As Boolean) As Boolean
        Dim answer As String

        While (True)
            Console.Write("{0}? (enter 'yes' or 'no'.", label)
            If (defVal) Then
                Console.Write(" default=yes): ")
            Else
                Console.Write(" default=no): ")
            End If
            answer = Console.ReadLine().ToLower()

            If (0 = answer.Length) Then
                Return defVal
            End If
            If (answer.StartsWith("n")) Then
                Return False
            End If
            If (answer.StartsWith("y")) Then
                Return True
            End If
            Console.WriteLine("Please respond 'yes' or 'no':")
        End While
    End Function

    Function numberPrompt(ByVal label As String, ByVal min As Double, ByVal max As Double, ByVal multiplier As Double, ByVal defval As Double) As Double
        Dim answer As String
        Dim value As Double

        While (True)
            Console.Write("{0}? (enter a value between {1} and {2}. default={3}): ", label, min / multiplier, max / multiplier, defval)
            answer = Console.ReadLine()
            If (answer.Length > 0) Then
                value = Double.Parse(answer)
            Else
                value = defval
            End If
            value = value * multiplier
            If ((value >= min) And (value <= max)) Then
                Return value
            End If
            Console.WriteLine("     Response must be between {0} and {1}!", min / multiplier, max / multiplier)
        End While
    End Function


    Sub setupAcquisition(ByVal driver As AgM9392)
        Dim PRESELECTOR_MIN_FREQ As New Double
        Dim prompt As String

        PRESELECTOR_MIN_FREQ = 2900000000.0
        prompt = String.Format("Use Preselector({0}-{1}GHz)", PRESELECTOR_MIN_FREQ / 1000000000.0, driver.Acquisition.MaxFrequency / 1000000000.0)
        driver.Acquisition.PreselectorEnabled = binaryPrompt(prompt, False)
        driver.Acquisition.Frequency = numberPrompt("Frequency (GHz)", driver.Acquisition.MinFrequency, driver.Acquisition.MaxFrequency, 1000000000.0, 8.0)
        If ((driver.Acquisition.Frequency < PRESELECTOR_MIN_FREQ) And (True = driver.Acquisition.PreselectorEnabled)) Then
            Console.WriteLine("     DISABLING preselector (frequency too low)")
            driver.Acquisition.PreselectorEnabled = False
        End If
        driver.Acquisition.Power = numberPrompt("Power (dBm)", driver.Acquisition.MinPower, driver.Acquisition.MaxPower, 1, -10)
        driver.Acquisition.Bandwidth = numberPrompt("bandwidth (kHz)", 0, driver.Acquisition.MaxBandwidth, 1000, 250)
        driver.Acquisition.Time = numberPrompt("Acquisition Time(ms)", 0, driver.Acquisition.MaxTime, 0.001, 10)
        driver.Calibration.FieldCalibration.Enabled = binaryPrompt("Calibration", True)
    End Sub

    Sub acquireMeasurement(ByVal driver as AgM9392, ByVal timeout As Double)
        Dim nsam As Int32
        Dim numCopied As Int32

        Console.WriteLine("")
        Console.WriteLine("Initiate measurement...")
        driver.Measurements.Initiate()
        driver.Measurements.WaitForInitiateComplete(timeout)
        Console.WriteLine("Arming...")
        driver.Measurements.Arm()

        driver.Measurements.WaitForData(timeout)

        Console.WriteLine("RMS Power = {0} dBm.", driver.Measurements.RmsPower)
        Console.WriteLine("Peak Power = {0} dBm.", driver.Measurements.PeakPower)

        nsam = driver.Measurements.NumberOfSamples

        Dim complexdata(0 To 2 * nsam) As Single
        driver.Measurements.GetData(complexdata, numCopied)
        Console.WriteLine("Acquired {0} complex data samples at {1} per second.", nsam, driver.Measurements.SampleRate)
        nsam = numberPrompt("Number of samples to display", 0, numCopied / 2, 1, numCopied / 2)
        Console.WriteLine("   #       I         Q")
        For n As Int32 = 0 To nsam - 1
            Console.WriteLine("   {0}     {1}     {2}", n, complexdata(2 * n), complexdata(2 * n + 1))
        Next
    End Sub

    Sub Main()
        Dim args() As String

        args = Split(Command$)

        '   * You can change the code below to hard-code your resource descriptor and simulation mode, or you can pass the resource
        '   * descriptor in the command line when you run the example program to use that hardware in non-simulation mode.
        '   *
        '   * The resource descriptor is the same value as the Selected Instrument field of the SFPs (Soft Front Panel)
        '   * connection dialog.   This can be a comma or semicolon separated list of module addresses such as
        '   *     PXI10::15::0::INSTR;PXI10::16::0::INSTR;PXI10::17::0::INSTR;PXI10::18::0::INSTR
        '   * or the name of a saved Instrument Connection created by the SFP such as
        '   *     PreselectedVSA
        '   * Refer to the SFP Help topic Connect to Instruments and Modules for more details.

        ' Pass in a command line argument as the resource descriptor, if none, will default
        Dim resource As String = "PXI20::13::INSTR"
        Dim options As String = "QueryInstrStatus=true, Simulate=true, DriverSetup= Model=, Trace=false"
        If ((args.Length > 0) And (args(0).Length > 0)) Then
            resource = args(0)
            options = "QueryInstrStatus=true, Simulate=false, DriverSetup= Model=, Trace=false"
        End If

        ' Create an instance of the driver
        Dim driver As New AgM9392

        Try
            Dim idquery As Boolean = True
            Dim reset As Boolean = True

            ' Initialize the driver.  See driver help topic "Initializing the IVI-COM Driver" for additional information
            driver.Initialize(resource, idquery, reset, options)
            Console.WriteLine("Driver Initialized")

            ' Get driver Identity properties.
            Console.WriteLine("Identifier:  {0}", driver.Identity.Identifier)
            Console.WriteLine("Revision:    {0}", driver.Identity.Revision)
            Console.WriteLine("Vendor:      {0}", driver.Identity.Vendor)
            Console.WriteLine("Description: {0}", driver.Identity.Description)
            Console.WriteLine("Model:       {0}", driver.Identity.InstrumentModel)
            Console.WriteLine("FirmwareRev: {0}", driver.Identity.InstrumentFirmwareRevision)
            Console.WriteLine("Serial #:    {0}", driver.System.SerialNumber)
            Console.WriteLine("Simulate:    {0}", driver.DriverOperation.Simulate)
            Console.WriteLine()

            setupAcquisition(driver)
            If (binaryPrompt("Initiate", True)) Then
                acquireMeasurement(driver, 1000)
            End If

            ' Polling the instrument for queued errors is not necessary.  No errors are queued.
            ' rather, each of the above driver calls would have thrown an exception if an error occurred.
            ' Any thrown exceptions would be handled in the catch clause below:

        Catch err As System.Exception
            Console.WriteLine()
            Console.WriteLine("Exception Error:")
            Console.WriteLine("  " + err.Message())
        End Try

        ' Close driver if initialized.
        If (driver.Initialized) Then
            driver.Close()
            Console.WriteLine("Driver Closed")
        End If

        Console.WriteLine()
        Console.Write("Done - Press Enter to Exit ")
        Console.ReadLine()
    End Sub
End Module
