﻿Imports Ivi.Visa.Interop

Namespace VB_FieldCalibration
    ''' <summary>
    ''' VisaSession aggregates the operations required to open and
    ''' close a VISA session using Ivi.Visa.Interop.  It exposes
    ''' the session to derived classes.
    ''' 
    ''' This class uses Ivi.Visa.Interop (rather than VisaComLib)
    ''' so the program can connect to the instrument using either
    ''' Agilent I/O or National Instruments VISA.
    ''' </summary>
    Public Class VisaSession
        Protected Shared mResourceManager As New ResourceManager()
        Protected mSession As IMessage
        Protected mFixedCulture As New Globalization.CultureInfo("en-US")

        ''' <summary>
        ''' Open a VISA session for the specified VISA resource string.
        ''' </summary>
        ''' <param name="resource">VISA resource, may be an alias</param>
        Protected Sub OpenSession(ByVal resource As String)
            Const options As [String] = ""
            Const openTimeout As Integer = 2000
            ' ms
            Dim session As IVisaSession = mResourceManager.Open(resource, AccessMode.EXCLUSIVE_LOCK, openTimeout, options)

            ' "Cast" (which does QueryInterface) the VISA Session into the form we need
            mSession = DirectCast(session, IMessage)
            mSession.SendEndEnabled = False
            mSession.TerminationCharacter = CByte(AscW(ControlChars.Lf))
            mSession.TerminationCharacterEnabled = True
            mSession.Timeout = 5000
            ' ms            
        End Sub

        ''' <summary>
        ''' Close the VISA session
        ''' </summary>
        Protected Sub CloseSession()
            If mSession IsNot Nothing Then
                mSession.Close()
                mSession = Nothing
            End If
        End Sub

        ''' <summary>
        ''' Indicate if the VISA session has been opened
        ''' </summary>
        ''' <returns></returns>
        Protected Function IsSessionOpen() As Boolean
            Return mSession IsNot Nothing
        End Function
    End Class
End Namespace
